@@ -5,9 +5,9 @@ import pytest
 
 from wxutils import (Button, CEN, Check, Choice, EditableListBox,
                      FRAMESTYLE, FileOpen, FileSave, FloatCtrl, Font,
-                     GUIColors, GridPanel, HLine, HyperText, LCEN, LEFT,
+                     COLORS, GridPanel, HLine, HyperText, LCEN, LEFT,
                      MenuItem, Popup, RCEN, RIGHT, RowPanel, SimpleText,
-                     TextCtrl, fix_filename, get_icon, pack)
+                     TextCtrl, get_icon, pack)
 
 class TestCase(unittest.TestCase):
     def test_imports(self):
